==> download.php?FileName=terralib-5.3.2.zip: src/terralib/qt/plugins/rp/ContrastAction.cpp <==
/*  Copyright (C) 2008 National Institute For Space Research (INPE) - Brazil.

    This file is part of the TerraLib - a Framework for building GIS enabled applications.

    TerraLib is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License,
    or (at your option) any later version.

    TerraLib is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with TerraLib. See COPYING. If not, write to
    TerraLib Team at <terralib-team@terralib.org>.
 */

/*!
  \file terralib/qt/plugins/rp/ContrastAction.cpp

  \brief This file defines the Contrast class
*/

// Terralib
#include "../../../dataaccess/utils/Utils.h"
#include "../../../raster/BandProperty.h"
#include "../../../raster/RasterProperty.h"
#include "../../af/events/LayerEvents.h"
#include "../../af/ApplicationController.h"
#include "../../af/BaseApplication.h"
#include "ContrastAction.h"

// Qt
#include <QObject>
#include <QMessageBox>
#include <QApplication>

// STL
#include <memory>

te::qt::plugins::rp::ContrastAction::ContrastAction(QMenu* menu, QMenu* popupMenu):te::qt::plugins::rp::AbstractAction(menu, popupMenu)
{
  createAction(tr("Contrast...").toUtf8().data(), "histogram");

  m_action->setObjectName("Processing.Raster Processing.Contrast");
}

te::qt::plugins::rp::ContrastAction::~ContrastAction()
{
}

void te::qt::plugins::rp::ContrastAction::onActionActivated(bool checked)
{
  te::map::AbstractLayerPtr layer = getCurrentLayer();

  if(!layer.get())
  {
    QMessageBox::warning(te::qt::af::AppCtrlSingleton::getInstance().getMainWindow(), tr("Warning"), tr("There is no selected raster layer."));
    return;
  }

  QApplication::setOverrideCursor(Qt::WaitCursor);

  if(layer->getVisibility() != te::map::VISIBLE)
  {
    QApplication::restoreOverrideCursor();
    QMessageBox::warning(te::qt::af::AppCtrlSingleton::getInstance().getMainWindow(), tr("Warning"), tr("The layer is not checked!"));
    return;
  }

  std::unique_ptr<te::da::DataSetType> dsType = layer->getSchema();

  te::rst::RasterProperty* rasterProp = te::da::GetFirstRasterProperty(dsType.get());

  if (rasterProp->getBandProperties().empty())
  {
    QApplication::restoreOverrideCursor();
    QMessageBox::warning(te::qt::af::AppCtrlSingleton::getInstance().getMainWindow(), tr("Warning"), tr("Layers without Band information!"));
    return;
  }

  if(rasterProp->getBandProperties()[0]->m_colorInterp == te::rst::PaletteIdxCInt)
  {
    QApplication::restoreOverrideCursor();
    QMessageBox::warning(te::qt::af::AppCtrlSingleton::getInstance().getMainWindow(), tr("Warning"), tr("Layers with raster palette are not able to apply contrast!"));
    return;
  }

  // Register the application framework listener
  te::qt::af::AppCtrlSingleton::getInstance().addListener(this, te::qt::af::RECEIVER);

  m_contrastDlg.reset(new te::qt::widgets::ContrastDialogForm(te::qt::af::AppCtrlSingleton::getInstance().getMainWindow()));

  connect(m_contrastDlg.get(), SIGNAL(addLayer(te::map::AbstractLayerPtr)), this, SLOT(addLayer(te::map::AbstractLayerPtr)));
  connect(m_contrastDlg.get(), SIGNAL(closeTool()), this, SLOT(closeTool()));

  te::qt::af::BaseApplication* ba = dynamic_cast<te::qt::af::BaseApplication*>(te::qt::af::AppCtrlSingleton::getInstance().getMainWindow());

  QActionGroup* mapEditionTools = te::qt::af::AppCtrlSingleton::getInstance().findActionGroup("Map.ToolsGroup");
  assert(mapEditionTools);

  m_contrastDlg->setModal(false);
  m_contrastDlg->setMapDisplay(ba->getMapDisplay());
  m_contrastDlg->setActionGroup(mapEditionTools);
  m_contrastDlg->set(layer);
  m_contrastDlg->setConfigurations();

  QApplication::restoreOverrideCursor();

  m_contrastDlg->show();
}

void te::qt::plugins::rp::ContrastAction::onPopUpActionActivated(bool checked)
{
  te::map::AbstractLayerPtr layer = getCurrentLayer();

  if(layer.get())
  {
    te::qt::widgets::ContrastDialogForm dlg(te::qt::af::AppCtrlSingleton::getInstance().getMainWindow());

    dlg.set(layer);

    dlg.exec();
  }
  else
  {
    QMessageBox::warning(te::qt::af::AppCtrlSingleton::getInstance().getMainWindow(), tr("Warning"), tr("The layer selected is invalid or does not have an raster representation."));
  }
}

void te::qt::plugins::rp::ContrastAction::onApplicationTriggered(te::qt::af::evt::Event* e)
{
  switch (e->m_id)
  {
    case te::qt::af::evt::LAYER_SELECTED:
    {
      te::qt::af::evt::LayerSelected* evt = static_cast<te::qt::af::evt::LayerSelected*>(e);

      te::map::AbstractLayerPtr layer = evt->m_layer;
      assert(layer);

      if(!layer)
        return;

      if(layer->getVisibility() != te::map::VISIBLE)
      {
        QMessageBox::warning(te::qt::af::AppCtrlSingleton::getInstance().getMainWindow(), tr("Warning"), tr("The layer is not checked!"));
        return ;
      }

      if(m_contrastDlg)
        m_contrastDlg->resetWindow(layer);
    }
    break;

    case te::qt::af::evt::DRAWING_FINISHED:
    {
      m_contrastDlg->onMapDisplayExtentChanged();
    }
    break;

    default:
      break;
  }
}

void te::qt::plugins::rp::ContrastAction::addLayer(te::map::AbstractLayerPtr outputLayer)
{
  //add new layer
  addNewLayer(outputLayer);
}

void te::qt::plugins::rp::ContrastAction::closeTool()
{
  te::qt::af::AppCtrlSingleton::getInstance().removeListener(this);

  m_contrastDlg.reset(0);
}

==> download.php?FileName=terralib-5.4.0.zip: src/terralib/qt/plugins/rp/ContrastAction.cpp <==
/*  Copyright (C) 2008 National Institute For Space Research (INPE) - Brazil.

    This file is part of the TerraLib - a Framework for building GIS enabled applications.

    TerraLib is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License,
    or (at your option) any later version.

    TerraLib is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with TerraLib. See COPYING. If not, write to
    TerraLib Team at <terralib-team@terralib.org>.
 */

/*!
  \file terralib/qt/plugins/rp/ContrastAction.cpp

  \brief This file defines the Contrast class
*/

// Terralib
#include "../../../dataaccess/utils/Utils.h"
#include "../../../raster/BandProperty.h"
#include "../../../raster/RasterProperty.h"
#include "../../af/events/LayerEvents.h"
#include "../../af/ApplicationController.h"
#include "../../af/BaseApplication.h"
#include "ContrastAction.h"

// Qt
#include <QObject>
#include <QMessageBox>
#include <QApplication>

// STL
#include <memory>

te::qt::plugins::rp::ContrastAction::ContrastAction(QMenu* menu, QMenu* popupMenu):te::qt::plugins::rp::AbstractAction(menu, popupMenu)
{
  createAction(tr("Contrast...").toUtf8().data(), "histogram");

  m_action->setObjectName("Processing.Raster Processing.Contrast");
}

te::qt::plugins::rp::ContrastAction::~ContrastAction() = default;

void te::qt::plugins::rp::ContrastAction::onActionActivated(bool /*checked*/)
{
  std::list<te::map::AbstractLayerPtr> layersList = getLayers();

  if(layersList.empty())
  {
     QMessageBox::warning(te::qt::af::AppCtrlSingleton::getInstance().getMainWindow(), tr("Contrast"), tr("There is no selected raster layer."));
     return;
  }

  // Register the application framework listener
  te::qt::af::AppCtrlSingleton::getInstance().addListener(this, te::qt::af::RECEIVER);

  m_contrastDlg.reset(new te::qt::widgets::ContrastDialogForm(te::qt::af::AppCtrlSingleton::getInstance().getMainWindow()));

  connect(m_contrastDlg.get(), SIGNAL(addLayer(te::map::AbstractLayerPtr)), this, SLOT(addLayer(te::map::AbstractLayerPtr)));
  connect(m_contrastDlg.get(), SIGNAL(closeTool()), this, SLOT(closeTool()));

  te::qt::af::BaseApplication* ba = dynamic_cast<te::qt::af::BaseApplication*>(te::qt::af::AppCtrlSingleton::getInstance().getMainWindow());

  QActionGroup* mapEditionTools = te::qt::af::AppCtrlSingleton::getInstance().findActionGroup("Map.ToolsGroup");
  assert(mapEditionTools);

  m_contrastDlg->setMapDisplay(ba->getMapDisplay());
  m_contrastDlg->setActionGroup(mapEditionTools);
  m_contrastDlg->setModal(false);
  m_contrastDlg->setList(layersList);

  m_contrastDlg->show();
}

void te::qt::plugins::rp::ContrastAction::onApplicationTriggered(te::qt::af::evt::Event* e)
{
  switch (e->m_id)
  {
    case te::qt::af::evt::LAYER_SELECTED:
    {
      te::qt::af::evt::LayerSelected* evt = static_cast<te::qt::af::evt::LayerSelected*>(e);

      te::map::AbstractLayerPtr layer = evt->m_layer;
      assert(layer);

      if(!layer)
        return;

      if(layer->getVisibility() != te::map::VISIBLE)
      {
        QMessageBox::warning(te::qt::af::AppCtrlSingleton::getInstance().getMainWindow(), tr("Warning"), tr("The layer is not checked!"));
        return ;
      }

    }
    break;

    case te::qt::af::evt::DRAWING_FINISHED:
    {
      m_contrastDlg->onMapDisplayExtentChanged();
    }
    break;

    default:
      break;
  }
}

void te::qt::plugins::rp::ContrastAction::addLayer(te::map::AbstractLayerPtr outputLayer)
{
  //add new layer
  addNewLayer(outputLayer);
}

void te::qt::plugins::rp::ContrastAction::closeTool()
{
  te::qt::af::AppCtrlSingleton::getInstance().removeListener(this);

  m_contrastDlg.reset(nullptr);
}
